@@ -41,6 +41,14 @@ except:
     pass
 
 
+# Code with these names have an implicit .0 in them
+COMPREHENSION_FN_NAMES = frozenset((
+    "<setcomp>",
+    "<dictcomp>",
+    "<listcomp>",
+    "<genexpr>",
+))
+
 class Function(object):
     """Function(name, code, globals, argdefs, closure, vm,  kwdefaults={},
                 annotations={}, doc=None, qualname=None)
@@ -156,9 +164,29 @@ class Function(object):
         # In Python 3.x is varous generators and list comprehensions have a .0 arg
         # but inspect doesn't show that. In the various MAKE_FUNCTION routines,
         # we will detect this and store True in this field when appropriate.
-        self.has_dot_zero = False
+        if not argdefs and self.__name__.split(".")[-1] in COMPREHENSION_FN_NAMES:
+            self.has_dot_zero = True
+        else:
+            self.has_dot_zero = False
 
-        # Sometimes, we need a real Python function.  This is for that.
+        # From byterun.py:
+        #   Sometimes, we need a real Python function. This is for that.
+        #
+        #
+        # An elaboration of the above pity comment may be helpful.
+        # Until this project emulates more functions, we rely heavily
+        # on some built-in, or standard library
+        # functions. `__build_class__` is an example of a builtin;
+        # `import` is another example.  Many of Python's standard
+        # library inspect routines require native functions, not our
+        # emulated classes and types.
+        #
+        # For the `inspect` module, we've started providing equivalent
+        # alternatives, but overall more of this needs to be done.
+        #
+        # The intent in providing native functions is for use in type
+        # testing, mostly. The functios should not be run, since that defeats our
+        # ability to trace functions.
         kw = {
             "argdefs": self.func_defaults,
         }
@@ -209,6 +237,8 @@ class Function(object):
             callargs = {".0": args[0]}
         elif self._func and self.version == PYTHON_VERSION:
             # Perhaps this branch can go and we just use the others.
+            # It will require a *lot* more code from inspect.py to be added:
+            # classes Signature, Parameter, etc.
             callargs = inspect.getcallargs(self._func, *args, **kwargs)
         else:
             if self.version >= 3.0:
@@ -491,7 +521,7 @@ if __name__ == "__main__":
     foo = Foo()
     myMfoo = Method(foo.bar, Foo, Foo.bar)
     Mfoo = types.MethodType(foo.bar, Foo)
-    # Should __name__, __func__ and __self__ match?
+    # Should __name__, _func and __self__ match?
     for attr in "__doc__".split():
         assert getattr(Mfoo, attr) == getattr(myMfoo, attr), attr
 
